@@ -1,3 +1,5 @@
+import json
+import os
 import time
 import hmac
 import hashlib
@@ -5,16 +7,23 @@ import base64
 import urllib.parse
 import requests
 
-from ..config.config_base import config
+from ..config.config_client import ConfigClient
+
+LIB_APP_ID = "winhye_common"
+app_id = os.environ.get("APP_ID", "NOT_EXIST")
+if app_id == "NOT_EXIST":
+    app_id = LIB_APP_ID
+ConfigClient.init(app_id)
 
 
 class DingAlarm:
     def __init__(self):
-        alarm_config = config.get_alarm_config()
-        self.secret = alarm_config["secret"]
-        self.url = alarm_config["url"]
-        self.atMobiles = alarm_config["atMobiles"]
-        self.isAtAll = alarm_config["isAtAll"]
+        alarm_conf = ConfigClient.get_configger("winhye_software.common")
+        alarm_config = alarm_conf.get_group("alarm")
+        self.secret = alarm_config.secret
+        self.url = alarm_config.url
+        self.atMobiles = json.loads(alarm_config.atMobiles)
+        self.isAtAll = eval(alarm_config.isAtAll)
 
     def get_sign(self):
         timestamp = str(round(time.time() * 1000))
