@@ -26,7 +26,7 @@ class HostAddressFilter(logging.Filter):
 
 
 class RequestAddressFilter(logging.Filter):
-    """Add request address to logging.format, "127.0.0.winhye_handlers" for non-flask scenario
+    """Add request address to logging.format, "127.0.0.1" for non-flask scenario
     """
 
     def filter(self, record):
@@ -37,7 +37,7 @@ class RequestAddressFilter(logging.Filter):
                 source_ip = flask.request.remote_addr
         except:
             # not in Flask scope
-            source_ip = "127.0.0.winhye_handlers"
+            source_ip = "127.0.0.1"
         record.source_ip = source_ip
         return True
 
@@ -51,3 +51,11 @@ class ConcurrentIdFilter(logging.Filter):
         concurrent_id = get_ident()
         record.concurrent_id = concurrent_id
         return True
+
+
+class NameFilter(logging.Filter):
+    def filter(self, record):
+        import getpass
+        if getpass.getuser() == record.name:
+            return True
+        return False
